netapp_ontap.models.performance_metric_io_type_rwt API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.performance_metric_io_type_rwt`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class PerformanceMetricIoTypeRwtSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the PerformanceMetricIoTypeRwt object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `read GET POST PATCH`

    Performance metric for read I/O operations.

    Example: 200

  `total GET POST PATCH`

    Performance metric aggregated over all types of I/O operations.

    Example: 1000

  `write GET POST PATCH`

    Peformance metric for write I/O operations.

    Example: 100